@@ -1,4 +1,4 @@
-__version__ = "1.0.88"
+__version__ = "1.0.92"
 
 import kappadata.caching
 import kappadata.common
@@ -35,6 +35,8 @@ from .datasets.kd_subset import KDSubset
 from .datasets.kd_wrapper import KDWrapper
 # transforms base
 from .transforms.base.kd_compose_transform import KDComposeTransform
+from .transforms.base.kd_scheduled_transform import KDScheduledTransform
+from .transforms.base.kd_stochastic_transform import KDStochasticTransform
 from .transforms.base.kd_transform import KDTransform
 # transforms
 from .transforms.image_pos_embed_grid import ImagePosEmbedGrid
@@ -51,6 +53,7 @@ from .transforms.kd_random_grayscale import KDRandomGrayscale
 from .transforms.kd_random_horizontal_flip import KDRandomHorizontalFlip
 from .transforms.kd_random_resized_crop import KDRandomResizedCrop
 from .transforms.kd_random_solarize import KDRandomSolarize
+from .transforms.kd_resize import KDResize
 # transforms norm
 from .transforms.norm.kd_image_norm import KDImageNorm
 from .transforms.norm.kd_image_range_norm import KDImageRangeNorm
@@ -82,4 +85,6 @@ from .wrappers.sample_wrappers.one_hot_wrapper import OneHotWrapper
 from .wrappers.sample_wrappers.x_transform_wrapper import XTransformWrapper
 from .wrappers.torch_wrapper import TorchWrapper
 # utils
-from .utils.transform_utils import get_denorm_transform, get_norm_transform, flatten_transform
\ No newline at end of file
+from .utils.transform_utils import get_denorm_transform, get_norm_transform, flatten_transform
+# factory
+from .factory import object_to_transform
\ No newline at end of file
